@@ -20,7 +20,6 @@
 #include "context.h"
 #include <jack/jack.h>
 
-u_long id = 1330135598;
 u_long options = BEQ_THREAD;
 
 /* JACK data */
@@ -62,7 +61,7 @@ process(jack_nframes_t nframes, void *arg)
 
     for (chn = 0; chn < 2; chn++) {
       in = jack_port_get_buffer(input_ports[chn], nframes);
-      if (in != NULL) {
+      if (NULL != in) {
         for (i = 0; i < nframes; i++, idx++) {
           data[chn][idx] = in[i];
         }
