@@ -37,7 +37,6 @@
 #define ABUF_SIZE 512
 /* #define ABUF_SIZE 256 */
 
-u_long id = 945287538;
 u_long options = BEQ_THREAD;
 
 #define OSS  "/dev/audio"
@@ -327,7 +326,7 @@ jthread(void *args)
         xperror("read");
       }
 
-      if ((ctx->input != NULL) && !ctx->input->mute) {
+      if ((NULL != ctx->input) && !ctx->input->mute) {
         int n2 = 0, idx;
 
         pthread_mutex_lock(&ctx->input->mutex);
