@@ -20,12 +20,11 @@
 #include "context.h"
 
 
-u_long id = 1075754710;
 uint32_t version = 0;
 u_long options = BE_GFX;
 u_long mode = OVERLAY;
 char desc[] = "Falling drops";
-
+char dname[] = "Drops";
 
 #define FACTOR 0.0005     /* empirical value, as usual */
 
@@ -223,7 +222,7 @@ run(Context_t *ctx)
   u_short nd;
   u_long idx;
 
-  if (ctx->input == NULL) {
+  if (NULL == ctx->input) {
     return;
   }
 
