@@ -20,11 +20,10 @@
 #include "context.h"
 
 
-u_long id = 949846112;
 uint32_t version = 0;
 u_long options = BE_LENS;
 char desc[] = "Emboss filter";
-
+char dname[] = "Emboss";
 
 void
 run(Context_t *ctx)
