@@ -20,11 +20,11 @@
 #include "context.h"
 
 
-u_long id = 1180546912;
 uint32_t version = 0;
 u_long options = BE_GFX|BEQ_FIRST;
 u_long mode = OVERLAY;
 char desc[] = "Cellular automaton";
+char dname[] = "Faders";
 
 /*
  * Adapted from:
