@@ -110,12 +110,12 @@
 #include "context.h"
 #include "parameters.h"
 
-u_long id = 1069709528;
 /* it's pseudo-3d */
 uint32_t version = 0;
 u_long options = BE_GFX;
 u_long mode = OVERLAY;
 char desc[] = "Flow effect";
+char dname[] = "Flow";
 
 #define MINTRAIL 2
 
@@ -176,7 +176,7 @@ get_parameters()
 
 
 void
-set_parameters(const json_t *in_parameters)
+set_parameters(const Context_t *ctx, const json_t *in_parameters)
 {
   int reload = 0;
   reload |= plugin_parameter_parse_int_range(in_parameters, BPP_FLOW_ID, &flow_id, 0, NB_FLOW-1) & PLUGIN_PARAMETER_CHANGED;
@@ -196,9 +196,11 @@ set_parameters(const json_t *in_parameters)
 
 
 json_t *
-parameters(const json_t *in_parameters)
+parameters(const Context_t *ctx, const json_t *in_parameters)
 {
-  set_parameters(in_parameters);
+  if (NULL != in_parameters) {
+    set_parameters(ctx, in_parameters);
+  }
 
   return get_parameters();
 }
@@ -292,7 +294,7 @@ Duffing(Par par, double x, double y, double z)
 }
 
 #define deallocate(p,t) {free(p); p=(t*)NULL; }
-#define allocate(p,t,s) if ((p=malloc(sizeof(t)*s))==NULL) \
+#define allocate(p,t,s) if (NULL == (p=malloc(sizeof(t)*s))) \
     {free_flow(sp);return;}
 
 
@@ -438,7 +440,7 @@ fill_flow_struct()
   }
 
   /* Allocate memory. */
-  if (sp->csegs == NULL) {
+  if (NULL == sp->csegs) {
     allocate(sp->csegs, Line_t, NCOL * sp->beecount * sp->taillen);
     allocate(sp->cnsegs, int, NCOL);
     allocate(sp->p, dvector, sp->beecount * sp->taillen);
@@ -476,24 +478,20 @@ create(Context_t *ctx)
 void
 run(Context_t *ctx)
 {
-  int         b, /*c,*/ i;
+  int         b, i;
   int         col, begin, end;
   double      M[3][3]; /* transformation matrix */
   flowstruct *sp;
   Buffer8_t *dst = passive_buffer(ctx);
 
-  /*
-    if (flows == NULL)
-    return;
-  */
   Buffer8_clear(dst);
 
   sp = &flow;
-  if (sp->csegs == NULL) {
+  if (NULL == sp->csegs) {
     return;
   }
 
-  if(!sp->view.depth) { /* simple 3D tumble */
+  if (!sp->view.depth) { /* simple 3D tumble */
     double      sint, cost, sinp, cosp;
     sp->tumble.theta += sp->tumble.dtheta;
     sp->tumble.phi += sp->tumble.dphi;
@@ -528,19 +526,19 @@ run(Context_t *ctx)
 
   /* <=- Bees -=> */
   for (b = 0; b < sp->beecount; b++) {
-    if(fabs(X(0, b)) > LOST_IN_SPACE ||
+    if (fabs(X(0, b)) > LOST_IN_SPACE ||
         fabs(Y(0, b)) > LOST_IN_SPACE ||
         /* if z is always invisible it's probably time */
         fabs(Z(0, b)) > ((sp->tumble.dphi!=0 ||
                           sp->tumble.phi!=0)?LOST_IN_SPACE:LOST_IN_TIME)) {
-      if(sp->view.depth && b==0) { /* lost camera - reset */
+      if (sp->view.depth && b==0) { /* lost camera - reset */
         (void)create(ctx);
         return;
       }
       continue;
     }
     /* Age the tail. */
-    for(i = sp->taillen - 1; i > 0; i--) {
+    for (i = sp->taillen - 1; i > 0; i--) {
       B(i, b) = B(i-1, b);
     }
 
@@ -566,12 +564,12 @@ run(Context_t *ctx)
 
     /* Fill the segment lists. */
 
-    if(sp->view.depth) { /* perspective view has special points */
-      if(b==0) { /* point of view */
+    if (sp->view.depth) { /* perspective view has special points */
+      if (b==0) { /* point of view */
         sp->centre.x=X(0, b);
         sp->centre.y=Y(0, b);
         sp->centre.z=Z(0, b);
-      } else if(b==1) { /* neighbour: used to compute local axes */
+      } else if (b==1) { /* neighbour: used to compute local axes */
         double x[3], p[3], x2=0, xp=0;
         int j;
 
@@ -585,13 +583,13 @@ run(Context_t *ctx)
         p[1] = Y(0, 1) - Y(1, 0);
         p[2] = Z(0, 1) - Z(1, 0);
 
-        for(i=0; i<3; i++) {
+        for (i=0; i<3; i++) {
           x2+= x[i]*x[i];    /* X . X */
           xp+= x[i]*p[i];    /* X . P */
           M[0][i] = x[i];    /* X */
         }
 
-        for(i=0; i<3; i++) {             /* (X x P) x X */
+        for (i=0; i<3; i++) {             /* (X x P) x X */
           M[1][i] = x2*p[i] - xp*x[i];  /* == (X . X) P - (X . P) X */
         }
 
@@ -600,13 +598,13 @@ run(Context_t *ctx)
         M[2][2] =  x[0]*p[1] - x[1]*p[0];
 
         /* normalise axes */
-        for(j=0; j<3; j++) {
+        for (j=0; j<3; j++) {
           double A=0;
-          for(i=0; i<3; i++) {
+          for (i=0; i<3; i++) {
             A+=M[j][i]*M[j][i];  /* sum squares */
           }
           A=sqrt(A);
-          for(i=0; i<3; i++) {
+          for (i=0; i<3; i++) {
             M[j][i]/=A;
           }
         }
@@ -619,7 +617,7 @@ run(Context_t *ctx)
 
     begin = 0; /* begin new trail */
     end = BMIN(sp->taillen, sp->count);
-    for(i=0; i < end; i++) {
+    for (i=0; i < end; i++) {
       double x=X(i,b)-sp->centre.x;
       double y=Y(i,b)-sp->centre.y;
       double z=Z(i,b)-sp->centre.z;
@@ -627,8 +625,8 @@ run(Context_t *ctx)
       double YM=M[1][0]*x + M[1][1]*y + M[1][2]*z;
       double ZM=M[2][0]*x + M[2][1]*y + M[2][2]*z+sp->view.height;
       double absx, absy;
-      if(sp->view.depth) {
-        if(XM <= 0) {
+      if (sp->view.depth) {
+        if (XM <= 0) {
           /* off screen - new trail */
           begin = i + 1;
           continue;
@@ -639,18 +637,18 @@ run(Context_t *ctx)
         absx=SCALE_X(XM);
         absy=SCALE_Y(YM);
       }
-      if(absx <= 0 || absx >= WIDTH ||
+      if (absx <= 0 || absx >= WIDTH ||
           absy <= 0 || absy >= HEIGHT) {
         /* off screen - new trail */
         begin = i + 1;
         continue;
       }
-      if(i > begin) {  /* complete previous segment */
+      if (i > begin) {  /* complete previous segment */
         sp->csegs[IX(col)].x2 = (short) absx;
         sp->csegs[IX(col)].y2 = (short) absy;
         sp->cnsegs[col]++;
       }
-      if(i < end -1) { /* start new segment */
+      if (i < end -1) { /* start new segment */
         sp->csegs[IX(col)].x1 = (short) absx;
         sp->csegs[IX(col)].y1 = (short) absy;
       }
@@ -674,7 +672,7 @@ run(Context_t *ctx)
   }
   /*for (b = 0; b < sp->cnsegs[col]; b++) {
 
-  if(++sp->count > 512)*/
+  if (++sp->count > 512)*/
   ++sp->count;
   if (flow_mode == MODE_RANDOM && b_timer_elapsed(changeme) > 30) {
     on_switch_on(ctx);
