@@ -19,7 +19,6 @@
 
 #include "context.h"
 
-u_long id = 947190672;
 uint32_t version = 0;
 u_long options = BE_GFX;
 u_long mode = OVERLAY;
@@ -159,19 +158,15 @@ static unistruct universe;
 static void
 free_galaxies(unistruct * gp)
 {
-  if (gp->galaxies != NULL) {
+  if (NULL != gp->galaxies) {
     int         i;
 
     for (i = 0; i < gp->ngalaxies; i++) {
       Galaxy     *gt = &gp->galaxies[i];
 
       free(gt->stars);
-      /*   if (gt->oldpoints != NULL)
-      (void) free((void *) gt->oldpoints);*/
-      /*   if (gt->newpoints != NULL)
-      (void) free((void *) gt->newpoints);*/
     }
-    (void) free((void *) gp->galaxies);
+    (void)free((void *) gp->galaxies);
     gp->galaxies = NULL;
   }
 }
@@ -201,7 +196,7 @@ startover()
   else if (gp->ngalaxies < MINGALAXIES) {
     gp->ngalaxies = MINGALAXIES;
   }
-  if (gp->galaxies == NULL) {
+  if (NULL == gp->galaxies) {
     gp->galaxies = xcalloc(gp->ngalaxies, sizeof(Galaxy));
   }
 
