@@ -21,7 +21,6 @@
 #include "infinity.h"
 
 
-u_long id = 1188927899;
 uint32_t version = 0;
 u_long options = BE_DISPLACE;
 char dname[] = "Infinity";
@@ -32,10 +31,13 @@ char desc[] = "Infinity effect";
  * Original source code has been heavily modified, to take only
  * the vector fields. So modified it's nearly a rewrite.
  * Changes have also been made to reflect style(9).
- * See the original infinity plugin source code for exact details
+ * See the original infinity plugin source code for exact details:
+ * https://github.com/dprotti/infinity-plugin
  */
 #define NB_FCT 6
 
+static Shuffler_t *shuffler = NULL;
+static VectorField_t *vf = NULL;
 static BTimer_t *timer = NULL;
 
 enum Mode { MODE_SELECTED = 0, MODE_RANDOM, MODE_NB } Mode_e;
@@ -53,35 +55,34 @@ get_parameters()
   json_t *params = json_object();
   plugin_parameters_add_string_list(params, BPP_MODE, MODE_NB, mode_list, mode);
   plugin_parameters_add_int(params, BPP_EFFECT, effect, -1, 1);
+  plugin_parameters_add_int(params, BPP_DELAY, delay, -1, 1);
 
   return params;
 }
 
 
 void
-set_parameters(const json_t *in_parameters)
+set_parameters(const Context_t *ctx, const json_t *in_parameters)
 {
-  int reload = 0;
-  reload |= plugin_parameter_parse_int_range(in_parameters, BPP_EFFECT, &effect, 0, NB_FCT-1) & PLUGIN_PARAMETER_CHANGED;
-  int restart = 0;
-  restart |= plugin_parameter_parse_int_range(in_parameters, BPP_DELAY, &delay, 1, 60) & PLUGIN_PARAMETER_CHANGED;
-
-  int mode_idx = 0;
-  if (plugin_parameter_parse_string_list_as_int_range(in_parameters, BPP_MODE, MODE_NB, mode_list, &mode_idx, 0, MODE_NB-1)) {
-    mode = (enum Mode)mode_idx;
-    reload = 1;
+  plugin_parameter_parse_int_range(in_parameters, BPP_EFFECT, &effect, 0, NB_FCT-1);
+  if (plugin_parameter_parse_int_range(in_parameters, BPP_DELAY, &delay, 1, 60) & PLUGIN_PARAMETER_CHANGED) {
+    b_timer_restart(timer);
   }
 
-  if (restart) {
-    b_timer_restart(timer);
+  if (plugin_parameter_parse_string_list_as_int_range(in_parameters, BPP_MODE, MODE_NB, mode_list, (int *)&mode, 0, MODE_NB-1) & PLUGIN_PARAMETER_CHANGED) {
+    if (mode == MODE_RANDOM) {
+      effect = Shuffler_get(shuffler);
+    }
   }
 }
 
 
 json_t *
-parameters(const json_t *in_parameters)
+parameters(const Context_t *ctx, const json_t *in_parameters)
 {
-  set_parameters(in_parameters);
+  if (NULL != in_parameters) {
+    set_parameters(ctx, in_parameters);
+  }
 
   return get_parameters();
 }
@@ -194,12 +195,6 @@ fct(t_complex a, guint32 n, gint32 p1, gint32 p2)   /* p1 et p2:0-4 */
 }
 
 
-/* Biniou plugin callbacks */
-static u_char num_effect = 0;
-static Shuffler_t *shuffler = NULL;
-static VectorField_t *vf = NULL;
-
-
 int8_t
 create(Context_t *ctx)
 {
@@ -226,7 +221,9 @@ destroy(Context_t *ctx)
 void
 on_switch_on(Context_t *ctx)
 {
-  num_effect = Shuffler_get(shuffler);
+  if (mode == MODE_RANDOM) {
+    effect = Shuffler_get(shuffler);
+  }
   b_timer_start(timer);
 }
 
@@ -234,11 +231,7 @@ on_switch_on(Context_t *ctx)
 void
 run(Context_t *ctx)
 {
-  if (mode == MODE_SELECTED) {
-    num_effect = effect;
-  }
-
-  VectorField_run(vf, ctx, num_effect);
+  VectorField_run(vf, ctx, effect);
 
   if ((mode == MODE_RANDOM) && (b_timer_elapsed(timer) > delay)) {
     on_switch_on(ctx);
