@@ -20,11 +20,10 @@
 #include "context.h"
 
 
-u_long id = 947430864;
 uint32_t version = 0;
 u_long options = BEQ_NORANDOM;
 char desc[] = "Poincare effect";
-
+char dname[] = "Poincare";
 
 void
 run(Context_t *ctx)
