@@ -20,12 +20,11 @@
 #include "context.h"
 
 
-u_long id = 948557759;
 uint32_t version = 0;
 u_long options = BEQ_COLORMAP;
 u_long mode = NONE;
 char desc[] = "Pulse the colormap";
-
+char dname[] = "Pulse";
 
 void
 on_switch_off(Context_t *ctx)
