@@ -26,12 +26,11 @@
 #include "context.h"
 #include "parameters.h"
 
-u_long id = 949178536;
 uint32_t version = 0;
 u_long options = BE_GFX;
 u_long mode = OVERLAY;
 char desc[] = "Rotors effect";
-
+char dname[] = "Rotors";
 
 #define MAX_ROTORS 16
 
@@ -62,16 +61,17 @@ static u_short nb_rotors, min_color, max_color;
 static float freq_base_moy, freq_base_ect;
 static float freq_var_moy, freq_var_ect;
 static float ampl_var_moy, ampl_var_ect;
-static float proba_visible, rotor_time;
+static float rotor_time;
 static int max_prof;
 
 static Rotor tab[MAX_ROTORS];
 static float time_step;
 
 static int nb_min_rotors = 0;
+static double proba_visible = 0;
 static int length = 0;
-static float speed = 0;
-static float scale = 0;
+static double speed = 0;
+static double scale = 0;
 
 static void post_init();
 
@@ -90,14 +90,14 @@ get_parameters()
 
 
 void
-set_parameters(const json_t *in_parameters)
+set_parameters(const Context_t *ctx, const json_t *in_parameters)
 {
   int reload = 0;
   reload |= plugin_parameter_parse_int_range(in_parameters, BPP_NB_MIN_ROTORS, &nb_min_rotors, 0, 1) & PLUGIN_PARAMETER_CHANGED;
-  reload |= plugin_parameter_parse_float_range(in_parameters, BPP_PROBA_VISIBLE, &proba_visible, 0, 1) & PLUGIN_PARAMETER_CHANGED;
+  reload |= plugin_parameter_parse_double_range(in_parameters, BPP_PROBA_VISIBLE, &proba_visible, 0, 1) & PLUGIN_PARAMETER_CHANGED;
   plugin_parameter_parse_int_range(in_parameters, BPP_LENGTH, &length, 10, 1000);
-  plugin_parameter_parse_float_range(in_parameters, BPP_SPEED, &speed, -10, 10);
-  reload |= plugin_parameter_parse_float_range(in_parameters, BPP_SCALE, &scale, 0, 2) & PLUGIN_PARAMETER_CHANGED;
+  plugin_parameter_parse_double_range(in_parameters, BPP_SPEED, &speed, -10, 10);
+  reload |= plugin_parameter_parse_double_range(in_parameters, BPP_SCALE, &scale, 0, 2) & PLUGIN_PARAMETER_CHANGED;
 
   if (reload) {
     post_init();
@@ -106,9 +106,11 @@ set_parameters(const json_t *in_parameters)
 
 
 json_t *
-parameters(const json_t *in_parameters)
+parameters(const Context_t *ctx, const json_t *in_parameters)
 {
-  set_parameters(in_parameters);
+  if (NULL != in_parameters) {
+    set_parameters(ctx, in_parameters);
+  }
 
   return get_parameters();
 }
@@ -121,7 +123,7 @@ prof_rotor_tree(Rotor *rotor)
 {
   int pg, pd;
 
-  if (rotor == NULL) {
+  if (NULL == rotor) {
     return 0;
   }
 
@@ -157,9 +159,9 @@ build_rotor_tree()
 
     /* Le resultat de la roulette est dans 'j' */
     arite[j]--;
-    if (tab[j].fg == NULL) {
+    if (NULL == tab[j].fg) {
       tab[j].fg = tab + i;
-    } else if (tab[j].fd == NULL) {
+    } else if (NULL == tab[j].fd) {
       tab[j].fd = tab + i;
     }
     arite[i] = 2;
@@ -176,10 +178,10 @@ init_rotor_tree(Rotor *rotor, float max_ray)
   int prof = prof_rotor_tree(rotor);
 
   rotor->rayon = (drand48() * (max_rnd_factor - min_rnd_factor) + min_rnd_factor) * (float)max_ray / (float)prof;
-  if (rotor->fg != NULL) {
+  if (NULL != rotor->fg) {
     init_rotor_tree(rotor->fg, max_ray - rotor->rayon);
   }
-  if (rotor->fd != NULL) {
+  if (NULL != rotor->fd) {
     init_rotor_tree(rotor->fd, max_ray - rotor->rayon);
   }
 }
@@ -305,7 +307,7 @@ create(Context_t *ctx)
 static void
 refresh(Rotor *rotor)
 {
-  if ((rotor->fg != NULL) || (rotor->fd != NULL))  {
+  if ((NULL != rotor->fg) || (NULL != rotor->fd))  {
     float f, arg, alpha;
     _Complex float pos_rel;
 
@@ -316,11 +318,11 @@ refresh(Rotor *rotor)
 
     pos_rel = rotor->rayon * cexp(ci * alpha);
 
-    if (rotor->fg != NULL) {
+    if (NULL != rotor->fg) {
       rotor->fg->centre = rotor->centre + pos_rel;
       refresh(rotor->fg);
     }
-    if (rotor->fd != NULL) {
+    if (NULL != rotor->fd) {
       rotor->fd->centre = rotor->centre - pos_rel;
       refresh(rotor->fd);
     }
