@@ -20,10 +20,10 @@
 #include "context.h"
 
 
-u_long id = 1325105220;
 uint32_t version = 0;
 u_long options = BE_GFX|BEQ_IMAGE|BEQ_MUTE_CAM|BEQ_NORANDOM;
 char desc[] = "1dTV plugin from the EffecTV project";
+char dname[] = "TV 1D";
 u_long mode = OVERLAY;
 
 static int line = 0;
