@@ -33,10 +33,11 @@
 #define MASK_SIZE  15 /* what size of chunks colorspace is divided */
 #define COLORCOUNT 5  /* how many colors are visible in each chunk */
 
-u_long id = 1552405159;
 uint32_t version = 0;
 u_long options = BE_GFX|BE_LENS|BEQ_MUTE_CAM;
 char desc[] = "Show webcam scrolling colors";
+char dname[] = "TV colrot";
+
 u_long mode = OVERLAY;
 
 static Pixel_t min1= 0, max1 = COLORCOUNT;
