@@ -20,10 +20,11 @@
 #include "context.h"
 
 
-u_long id = 1329763807;
 uint32_t version = 0;
 u_long options = BE_GFX|BEQ_MUTE_CAM|BEQ_NORANDOM;
 char desc[] = "DiffTV";
+char dname[] = "TV diff";
+
 u_long mode = OVERLAY;
 
 
