@@ -28,10 +28,11 @@
 #include "context.h"
 
 
-u_long id = 1324068377;
 uint32_t version = 0;
 u_long options = BE_GFX|BEQ_WEBCAM|BEQ_MUTE_CAM;
 char desc[] = "QuarkTV plugin from the EffecTV project";
+char dname[] = "TV quark";
+
 u_long mode = OVERLAY;
 
 #define MIN_FRAMES 11
@@ -89,7 +90,7 @@ static int draw(RGB32 *src, RGB32 *dest)
 
   memcpy(planetable[plane], src, video_area * PIXEL_SIZE);
 
-  for(i=0; i<video_area; i++) {
+  for (i=0; i<video_area; i++) {
     cf = (inline_fastrand()>>24)&(PLANES-1);
     dest[i] = (planetable[cf])[i];
     /* The reason why I use high order 8 bits is written in utils.c
@@ -97,7 +98,7 @@ static int draw(RGB32 *src, RGB32 *dest)
   }
 
   plane--;
-  if(plane<0) {
+  if (plane<0) {
     plane = PLANES - 1;
   }
 
