@@ -28,10 +28,11 @@
 #include "context.h"
 
 
-u_long id = 1325100452;
 uint32_t version = 0;
 u_long options = BE_GFX|BEQ_WEBCAM|BEQ_MUTE_CAM;
 char desc[] = "StreakTV plugin from the EffecTV project";
+char dname[] = "TV streak";
+
 u_long mode = OVERLAY;
 
 #define PLANES 32
