@@ -19,10 +19,11 @@
 
 #include "context.h"
 
-u_long id = 1172430309;
 uint32_t version = 0;
 u_long options = BE_GFX|BEQ_WEBCAM|BEQ_MUTE_CAM;
 char desc[] = "Webcam plugin";
+char dname[] = "TV webcam";
+
 u_long mode = OVERLAY;
 
 
