@@ -21,7 +21,6 @@
 
 #include "context.h"
 
-u_long id = 1228584968;
 u_long options = BE_NONE;
 
 
@@ -50,9 +49,7 @@ display_fonts()
 
   fonts = (char **)caca_get_font_list();
   printf("[i] caca_get_font_list:\n");
-  for (f = fonts;
-       *f != NULL;
-       f++) {
+  for (f = fonts; NULL != *f; f++) {
     printf("[i] font: %s\n", *f);
   }
 }
@@ -152,7 +149,7 @@ export(cucul_canvas_t *cv)
     // printf("[i] tmp_file= %s final= %s\n", fname[0], fname[1]);
 
     stream = fopen(fname[0], "w");
-    if (stream == NULL) {
+    if (NULL == stream) {
       xperror("fopen");
     }
 
