@@ -23,6 +23,7 @@
 #include "globals.h"
 #include "images.h"
 #include "colormaps.h"
+#include "paths.h"
 
 
 /* Auto-change timers and modes */
@@ -57,6 +58,7 @@ static void *
 biniou_images_thread(void *_args)
 {
   struct Images_thread_args *args = (struct Images_thread_args *)_args;
+
   Images_new(args->buf, args->themes);
   g_free(args->buf);
 
@@ -74,6 +76,7 @@ static void *
 biniou_colormaps_thread(void *_args)
 {
   struct Colormaps_thread_args *args = (struct Colormaps_thread_args *)_args;
+
   Colormaps_new(args->buf);
   g_free(args->buf);
 
@@ -81,6 +84,24 @@ biniou_colormaps_thread(void *_args)
 }
 
 
+static pthread_t paths_thread;
+static struct Paths_thread_args {
+  char *buf;
+} paths_thread_args;
+
+
+static void *
+biniou_paths_thread(void *_args)
+{
+  struct Paths_thread_args *args = (struct Paths_thread_args *)_args;
+
+  Paths_new(args->buf);
+  g_free(args->buf);
+
+  return NULL;
+}
+
+
 void
 biniou_new(const char *datadir, const char *pluginsdir,
            const char *schemes, const char *themes,
@@ -104,8 +125,13 @@ biniou_new(const char *datadir, const char *pluginsdir,
     colormaps_thread_args.buf = g_strdup_printf("%s/colormaps/", datadir);
     pthread_create(&colormaps_thread, NULL, biniou_colormaps_thread, (void *)&colormaps_thread_args);
 
+    /* Paths */
+    paths_thread_args.buf = g_strdup_printf("%s/paths/", datadir);
+    pthread_create(&paths_thread, NULL, biniou_paths_thread, (void *)&paths_thread_args);
+
     pthread_join(images_thread, NULL);
     pthread_join(colormaps_thread, NULL);
+    pthread_join(paths_thread, NULL);
   } else {
     Colormaps_new(NULL);
   }
@@ -207,17 +233,6 @@ biniou_start()
 
 void
 biniou_delete()
-{
-  VERBOSE(printf("[+] Freeing PRNG\n"));
-  b_rand_free();
-
-  VERBOSE(printf("[+] Freeing context\n"));
-  Context_delete(context);
-}
-
-
-void
-biniou_end()
 {
   if (NULL == context) {
     xerror("biniou_end() called but context is NULL\n");
@@ -225,15 +240,15 @@ biniou_end()
     context->running = 0;  /* This will stop plugins running as threads */
   }
 
-  /* TODO %d schemes as above */
+  VERBOSE(printf("[+] Freeing context\n"));
+  Context_delete(context);
+
   VERBOSE(printf("[+] Freeing schemes\n"));
   Schemes_delete();
 
-  /* TODO %d sequences as above */
   VERBOSE(printf("[+] Freeing sequences\n"));
   Sequences_free();
 
-  /* TODO %d plugins as above */
   VERBOSE(printf("[+] Freeing plugins\n"));
   Plugins_delete(plugins);
 
@@ -246,13 +261,21 @@ biniou_end()
     VERBOSE(printf("[+] Freeing %d colormap(s)\n", colormaps->size));
     Colormaps_delete(colormaps);
   }
+
+  if (NULL != paths) {
+    VERBOSE(printf("[+] Freeing %d paths(s)\n", paths->size));
+    Paths_delete();
+  }
+
+  VERBOSE(printf("[+] Freeing PRNG\n"));
+  b_rand_free();
 }
 
 
 void
 biniou_loop()
 {
-  biniou_go(0, 1);
+  biniou_go(0);
 }
 
 
@@ -269,10 +292,11 @@ biniou_stop()
 {
   if (NULL == context) {
     return 0;
-  }
+  } else {
+    context->running = 0;
 
-  context->running = 0;
-  return 1;
+    return 1;
+  }
 }
 
 
@@ -357,7 +381,7 @@ biniou_set_random_mode(const enum RandomMode r)
 
 
 void
-biniou_go(const u_long nb_frames, const u_char exit)
+biniou_go(const u_long nb_frames)
 {
   u_long frames = nb_frames;
 
@@ -366,22 +390,11 @@ biniou_go(const u_long nb_frames, const u_char exit)
 
     if (nb_frames != 0) {
       frames--;
-      if (!frames && exit) {
+      if (!frames) {
         context->running = 0;
       }
     }
   }
-
-  /* LA FIIIIIN DU MOOOOOOONDE! *DONG* *DONG* */
-  /* XXX move this outside,
-     a program will have to do:
-     biniou_start();
-     biniou_go(N);
-     biniou_end(); -> will have to do context->running = 0;
-  */
-  if (exit) {
-    biniou_end();
-  }
 }
 
 
