@@ -29,7 +29,7 @@ b_rand_init(void)
   uint32_t seed;
   char *seedstr;
 
-  if ((seedstr = getenv("LEBINIOU_SEED")) != NULL) {
+  if (NULL != (seedstr = getenv("LEBINIOU_SEED"))) {
     seed = xatol(seedstr);
     VERBOSE(printf("[i] Random seed set to %d\n", seed));
   } else {
@@ -46,7 +46,7 @@ b_rand_init(void)
 void
 b_rand_free(void)
 {
-  if (brand != NULL) {
+  if (NULL != brand) {
     g_rand_free(brand);
   }
 }
