@@ -50,7 +50,7 @@ Buffer8_clone(const Buffer8_t *src)
 void
 Buffer8_delete(Buffer8_t *buff)
 {
-  if (buff != NULL) {
+  if (NULL != buff) {
     xfree(buff->buffer);
   }
   xfree(buff);
@@ -324,7 +324,7 @@ Buffer8_substract_y(const Buffer8_t *buff1, const Buffer8_t *buff2, const Pixel_
     p = src;
     q = (short *)background;
     r = diff;
-    for(i=0; i<video_area; i++) {
+    for (i=0; i<video_area; i++) {
       R = ((*p)&0xff0000)>>(16-1);
       G = ((*p)&0xff00)>>(8-2);
       B = (*p)&0xff;
