@@ -154,7 +154,7 @@ CmapFader_set(CmapFader_t *cf)
 {
   cf->dst = colormaps->cmaps[cf->fader->target];
 
-  if (cf->dst->name != NULL) {
+  if (NULL != cf->dst->name) {
     if (libbiniou_verbose) {
       printf("[i] Using colormap '%s'\n", cf->dst->name);
     }
