@@ -50,7 +50,7 @@ extern unsigned short WIDTH, HEIGHT;
 #define HMINSCREEN (MINSCREEN>>1)
 #define HMAXSCREEN (MAXSCREEN>>1)
 
-/* char buffers toussa */
+/* character buffers */
 #define MAXLEN     _POSIX2_LINE_MAX
 
 /* maximum length of a sequence */
@@ -81,4 +81,7 @@ extern unsigned short WIDTH, HEIGHT;
 /* rotations factor */
 #define DEFAULT_ROT_FACTOR 4
 
+/* delay for ancillary threads (OSD, webcams) */
+#define THREADS_DELAY 40
+
 #endif /* __BINIOU_CONSTANTS_H */
