@@ -241,11 +241,11 @@ Context_delete(Context_t *ctx)
 
   VERBOSE(printf("[i] %lu frames, %lu events\n", ctx->frames, ctx->nb_events));
 
-  if (ctx->input_plugin != NULL) {
+  if (NULL != ctx->input_plugin) {
     Plugin_delete(ctx->input_plugin);
   }
 
-  for ( ; outputs != NULL; outputs = g_slist_next(outputs)) {
+  for ( ; NULL != outputs; outputs = g_slist_next(outputs)) {
     Plugin_t *output = (Plugin_t *)outputs->data;
 
     Plugin_delete(output);
@@ -272,7 +272,7 @@ Context_delete(Context_t *ctx)
   BufferRGBA_delete(ctx->rgba_buffers[ACTIVE_BUFFER]);
   VERBOSE(printf("\n"));
 
-  if (ctx->imgf != NULL) {
+  if (NULL != ctx->imgf) {
     VERBOSE(printf("[+] Freeing images fader\n"));
     ImageFader_delete(ctx->imgf);
 
@@ -280,7 +280,7 @@ Context_delete(Context_t *ctx)
     Alarm_delete(ctx->a_images);
   }
 
-  if (ctx->cf != NULL) {
+  if (NULL != ctx->cf) {
     VERBOSE(printf("[+] Freeing colormaps fader\n"));
     CmapFader_delete(ctx->cf);
 
@@ -309,7 +309,7 @@ Context_set_colormap(Context_t *ctx)
   /* have to change auto_colormaps ? */
   if (ctx->sm->next->auto_colormaps != -1) {
     /* find the cmap, if any. default cmap otherwise */
-    if (ctx->cf != NULL) {
+    if (NULL != ctx->cf) {
       ctx->cf->fader->target
         = (ctx->sm->next->cmap_id) ?
           Colormaps_index(ctx->sm->next->cmap_id) : 0;
@@ -331,7 +331,7 @@ Context_set_image(Context_t *ctx)
   /* have to change auto_images ? */
   if (ctx->sm->next->auto_images != -1) {
     /* find the image, if any. default image otherwise */
-    if (ctx->imgf != NULL) {
+    if (NULL != ctx->imgf) {
       ctx->imgf->fader->target
         = (ctx->sm->next->image_id) ?
           Images_index(ctx->sm->next->image_id) : 0;
@@ -355,12 +355,12 @@ Context_set(Context_t *ctx)
   tmp = g_list_first(ctx->sm->cur->layers);
 
   /* call on_switch_off() on old plugins */
-  while (tmp != NULL) {
+  while (NULL != tmp) {
     Layer_t *layer = tmp->data;
     Plugin_t *p = layer->plugin;
 
-    assert(p != NULL);
-    if (p->on_switch_off != NULL) {
+    assert(NULL != p);
+    if (NULL != p->on_switch_off) {
       p->on_switch_off(ctx);
     }
     tmp = g_list_next(tmp);
@@ -371,24 +371,24 @@ Context_set(Context_t *ctx)
 
   /* call on_switch_on() on new plugins */
   tmp = g_list_first(ctx->sm->next->layers);
-  while (tmp != NULL) {
+  while (NULL != tmp) {
     Layer_t *layer = (Layer_t *)tmp->data;
     Plugin_t *p = layer->plugin;
 
-    assert(p != NULL);
-    if (p->on_switch_on != NULL) {
+    assert(NULL != p);
+    if (NULL != p->on_switch_on) {
       p->on_switch_on(ctx);
     }
 
-    if (p->parameters != NULL) {
+    if (NULL != p->parameters) {
       /* Todo: check and use returned parameters ? */
-      json_decref(p->parameters(layer->plugin_parameters));
+      json_decref(p->parameters(ctx, layer->plugin_parameters));
     }
 
     tmp = g_list_next(tmp);
   }
 
-  Sequence_copy(ctx->sm->next, ctx->sm->cur);
+  Sequence_copy(ctx, ctx->sm->next, ctx->sm->cur);
 
   Context_update_auto(ctx);
 
@@ -401,7 +401,7 @@ void
 Context_update_auto(Context_t *ctx)
 {
   /* figure out auto_colormaps */
-  if (ctx->cf != NULL) {
+  if (NULL != ctx->cf) {
     if (ctx->sm->cur->auto_colormaps == -1) { // using a bare sequence
       ctx->cf->on = ctx->auto_colormaps;
     } else { // using a full sequence
@@ -419,14 +419,14 @@ Context_update_auto(Context_t *ctx)
   }
 
   /* figure out auto_images */
-  if (ctx->imgf != NULL) {
+  if (NULL != ctx->imgf) {
     if (ctx->sm->cur->auto_images == -1) { // using a bare sequence
       ctx->imgf->on = ctx->auto_images;
     } else { // using a full sequence
       ctx->imgf->on = ctx->sm->cur->auto_images;
     }
 
-    if (ctx->imgf->on && (images != NULL) && (images->size > 1)) {
+    if (ctx->imgf->on && (NULL != images) && (images->size > 1)) {
       /* select random image and reinitialize timer */
       ImageFader_random(ctx->imgf);
       Alarm_init(ctx->a_images);
@@ -446,14 +446,14 @@ Context_add_rand(Sequence_t *seq,
 
   do {
     p = Plugins_get_random(options, locked);
-    if (p == NULL) {
+    if (NULL == p) {
       return -1;
     }
-  } while (Sequence_find(seq, p) != NULL);
+  } while (NULL != Sequence_find(seq, p));
 
   Sequence_insert(seq, p);
 
-  if ((*p->options & BE_LENS) && !not_lens && (seq->lens == NULL)) {
+  if ((*p->options & BE_LENS) && !not_lens && (NULL == seq->lens)) {
     seq->lens = p;
   }
 
@@ -468,7 +468,7 @@ Context_randomize(Context_t *ctx)
   int rand;
 
   /* Use random image */
-  if (images != NULL) {
+  if (NULL != images) {
     if (images->size > 1) {
       rand = b_rand_int_range(0, images->size-1);
       ctx->auto_images = new->auto_images = b_rand_boolean();
@@ -479,7 +479,7 @@ Context_randomize(Context_t *ctx)
   }
 
   /* Use random colormap */
-  assert(colormaps != NULL);
+  assert(NULL != colormaps);
   if (colormaps->size > 1) {
     rand = b_rand_int_range(0, colormaps->size-1);
     ctx->auto_colormaps = new->auto_colormaps = b_rand_boolean();
@@ -501,7 +501,7 @@ void
 Context_insert_plugin(Context_t *ctx, Plugin_t *p)
 {
   /* switch the plugin on */
-  if (p->on_switch_on != NULL) {
+  if (NULL != p->on_switch_on) {
     VERBOSE(printf("[i] on_switch_on '%s' (%s)\n", p->name, p->dname));
     p->on_switch_on(ctx);
   }
@@ -514,7 +514,7 @@ void
 Context_remove_plugin(Context_t *ctx, Plugin_t *p)
 {
   /* switch the plugin off */
-  if (p->on_switch_off != NULL) {
+  if (NULL != p->on_switch_off) {
     VERBOSE(printf("[i] on_switch_off '%s' (%s)\n", p->name, p->dname));
     p->on_switch_off(ctx);
   }
@@ -556,17 +556,17 @@ Context_fps(const Context_t *ctx)
 void
 Context_previous_sequence(Context_t *ctx)
 {
-  if (ctx->sm->curseq != NULL) {
+  if (NULL != ctx->sm->curseq) {
     Sequence_t *s;
 
-    if (ctx->sm->curseq->next != NULL) {
+    if (NULL != ctx->sm->curseq->next) {
       ctx->sm->curseq = ctx->sm->curseq->next;
     } else {
       ctx->sm->curseq = g_list_first(sequences->seqs);
     }
 
     s = (Sequence_t *)ctx->sm->curseq->data;
-    Sequence_copy(s, ctx->sm->next);
+    Sequence_copy(ctx, s, ctx->sm->next);
 
     Context_set(ctx);
   }
@@ -576,17 +576,17 @@ Context_previous_sequence(Context_t *ctx)
 void
 Context_next_sequence(Context_t *ctx)
 {
-  if (ctx->sm->curseq != NULL) {
+  if (NULL != ctx->sm->curseq) {
     Sequence_t *s;
 
-    if (ctx->sm->curseq->prev != NULL) {
+    if (NULL != ctx->sm->curseq->prev) {
       ctx->sm->curseq = ctx->sm->curseq->prev;
     } else {
       ctx->sm->curseq = g_list_last(sequences->seqs);
     }
 
     s = (Sequence_t *)ctx->sm->curseq->data;
-    Sequence_copy(s, ctx->sm->next);
+    Sequence_copy(ctx, s, ctx->sm->next);
 
     Context_set(ctx);
   }
@@ -596,13 +596,13 @@ Context_next_sequence(Context_t *ctx)
 void
 Context_latest_sequence(Context_t *ctx)
 {
-  if (ctx->sm->curseq != NULL) {
+  if (NULL != ctx->sm->curseq) {
     Sequence_t *s;
 
     ctx->sm->curseq = g_list_last(sequences->seqs);
 
     s = (Sequence_t *)ctx->sm->curseq->data;
-    Sequence_copy(s, ctx->sm->next);
+    Sequence_copy(ctx, s, ctx->sm->next);
 
     Context_set(ctx);
   }
@@ -618,12 +618,12 @@ Context_random_sequence(Context_t *ctx)
   rand = Shuffler_get(sequences->shuffler);
 
   tmp = g_list_nth(sequences->seqs, rand);
-  assert(tmp != NULL);
+  assert(NULL != tmp);
 
   VERBOSE(printf("[s] Random sequence: %d\n", rand));
 
   ctx->sm->curseq = tmp;
-  Sequence_copy(tmp->data, ctx->sm->next);
+  Sequence_copy(ctx, tmp->data, ctx->sm->next);
 
   Context_set(ctx);
 }
@@ -641,7 +641,7 @@ Context_set_sequence(Context_t *ctx, const uint32_t id)
 
   assert(NULL != seq);
   ctx->sm->curseq = seq->layers;
-  Sequence_copy(seq, ctx->sm->next);
+  Sequence_copy(ctx, seq, ctx->sm->next);
 
   Context_set(ctx);
 }
@@ -667,7 +667,7 @@ Context_use_sequence_bank(Context_t *ctx, const u_char bank)
       }
     assert(NULL != seq);
     ctx->sm->curseq = seq->layers;
-    Sequence_copy(seq, ctx->sm->next);
+    Sequence_copy(ctx, seq, ctx->sm->next);
 
     ctx->bank[SEQUENCES] = bank;
 
@@ -741,50 +741,10 @@ Context_get_input_size(const Context_t *ctx)
 }
 
 
-void
-Context_set_phase_space_delay(Context_t *ctx, const uint8_t phase_space_delay)
-{
-  ctx->phase_space_delay = phase_space_delay;
-}
-
-
-uint8_t
-Context_get_phase_space_delay(const Context_t *ctx)
-{
-  return ctx->phase_space_delay;
-}
-
-
-uint32_t
-Context_get_phase_space_samples(const Context_t *ctx)
-{
-  if (ctx->input != NULL) {
-    return ctx->input->size - 2 * ctx->phase_space_delay;
-  } else {
-    return 0;
-  }
-}
-
-
-void
-Context_set_span_size(Context_t *ctx, const uint8_t span_size)
-{
-  assert(span_size > 0);
-  ctx->span_size = span_size;
-}
-
-
-uint8_t
-Context_get_span_size(const Context_t *ctx)
-{
-  return ctx->span_size;
-}
-
-
 void
 Context_set_volume_scale(Context_t *ctx, const double volume_scale)
 {
-  if (ctx->input != NULL) {
+  if (NULL != ctx->input) {
     ctx->input->volume_scale = volume_scale;
   }
 }
@@ -793,7 +753,7 @@ Context_set_volume_scale(Context_t *ctx, const double volume_scale)
 double
 Context_get_volume_scale(const Context_t *ctx)
 {
-  return (ctx->input != NULL) ? ctx->input->volume_scale : 0;
+  return (NULL != ctx->input) ? ctx->input->volume_scale : 0;
 }
 
 
@@ -828,7 +788,7 @@ Context_start_ulfius(Context_t *ctx)
 
   // Endpoint list declaration
   // GET
-  ulfius_add_endpoint_by_val(&ctx->instance, BULFIUS_GET, NULL, BULFIUS_PARAMETERS, 0, &callback_get_parameters, NULL);
+  ulfius_add_endpoint_by_val(&ctx->instance, BULFIUS_GET, NULL, BULFIUS_PARAMETERS, 0, &callback_get_parameters, ctx);
   ulfius_add_endpoint_by_val(&ctx->instance, BULFIUS_GET, NULL, BULFIUS_SEQUENCE, 0, &callback_get_sequence, ctx);
   ulfius_add_endpoint_by_val(&ctx->instance, BULFIUS_GET, NULL, BULFIUS_STATISTICS, 0, &callback_get_statistics, ctx);
   // POST
