@@ -126,26 +126,26 @@ Context_load_banks(Context_t *ctx)
 
   doc = xmlParseFile(filename);
   g_free(filename);
-  if (doc == NULL) {
+  if (NULL == doc) {
     return;
   }
 
   node = xmlDocGetRootElement(doc);
-  if (node == NULL) {
+  if (NULL == node) {
     xerror("Banks: xmlDocGetRootElement error\n");
   }
 
   node = xmlFindElement("banks", node);
-  if (node == NULL) {
+  if (NULL == node) {
     xerror("Banks: no <banks> found\n");
   }
 
   bank_node = node->xmlChildrenNode;
-  if (bank_node == NULL) { /* Empty banks.xml file */
+  if (NULL == bank_node) { /* Empty banks.xml file */
     return;
   }
 
-  while (bank_node != NULL) {
+  while (NULL != bank_node) {
     long tmp0, tmp1, tmp2;
     xmlChar *youhou;
     int res;
