@@ -31,7 +31,7 @@ ImageFader_new(const u_short size)
 
   pf->on = 0;
   pf->cur = Image8_new();
-  if (images != NULL) {
+  if (NULL != images) {
     pf->dst = images->imgs[0];
   }
   pf->fader = Fader_new(BUFFSIZE);
@@ -121,7 +121,7 @@ ImageFader_set(ImageFader_t *pf)
 
   pf->dst = images->imgs[fader->target];
 
-  if (pf->dst->name != NULL) {
+  if (NULL != pf->dst->name) {
     VERBOSE(printf("[i] Using image '%s'\r\n", pf->dst->name));
   } else {
     xerror("Image without name, WTF #@!\r\n");
