@@ -276,7 +276,7 @@ read_keyfile()
   GKeyFileFlags flags = G_KEY_FILE_NONE;
   g_autoptr(GError) error = NULL;
 
-  if (keyfile == NULL) {
+  if (NULL == keyfile) {
     home_dir = g_get_home_dir();
     keyfile = g_strdup_printf("%s/%s", home_dir, KEYFILE);
     VERBOSE(printf("[k] Using default configuration file: %s\n", keyfile));
