@@ -23,7 +23,7 @@
 #include "plugin.h"
 
 
-enum LayerMode { NONE=0, NORMAL, OVERLAY, XOR, AVERAGE, RANDOM, NB_LAYER_MODES } LayerMode_e;
+enum LayerMode { NONE = 0, NORMAL, OVERLAY, XOR, AVERAGE, RANDOM, NB_LAYER_MODES };
 
 typedef struct Layer_s {
   Plugin_t      *plugin;
