@@ -34,7 +34,7 @@ int32_t x_origin = INT32_MIN;
 int32_t y_origin = INT32_MIN;
 u_short width = DEFAULT_WIDTH;
 u_short height = DEFAULT_HEIGHT;
-enum RandomMode random_mode = BR_SCHEMES;
+enum RandomMode random_mode = BR_BOTH;
 char *pid_file  = "/tmp/lebiniou.pid";
 char *themes = NULL;
 uint8_t statistics = 0; // Display statistics
@@ -200,7 +200,7 @@ main(int argc, char **argv)
       printf("[i] No images\n");
     }
     libbiniou_verbose = 0;
-    biniou_go(1, 1);
+    biniou_go(1);
     biniou_delete();
     exit(0);
   }
