@@ -56,7 +56,7 @@ enum PluginOptions {
   BEQ_FIRST      = 1 << 26, /* insert plugin at the begining */
   BEQ_LAST       = 1 << 27, /* insert plugin at the end */
   BEQ_MUTE_CAM   = 1 << 28  /* some plugins (eg webcams) can be muted */
-} PluginOptions_e;
+};
 
 #define MAX_TYPES  29       /* all types available */
 
