@@ -28,9 +28,9 @@
 #ifdef DEBUG
 #define B_DLSYM(VAR, SYM)                                         \
   (VAR) = (void (*)(struct Context_s *)) dlsym(p->handle, (SYM)); \
-  if (libbiniou_verbose && ((VAR) != NULL))                       \
+  if (libbiniou_verbose && (NULL != (VAR)))                       \
     printf("[p] >> %s has '%s'\n", p->name, (SYM))
-#define B_GOTSYM(VAR, SYM) if ((VAR) != NULL)                     \
+#define B_GOTSYM(VAR, SYM) if (NULL != (VAR))                     \
     printf("[p] >> %s has '%s'\n", p->name, (SYM));
 #else
 #define B_DLSYM(VAR, SYM)                                         \
@@ -45,11 +45,11 @@ Plugin_load(Plugin_t *p)
   const char *error = NULL;
   u_long *_tmp;
 
-  assert(p != NULL);
+  assert(NULL != p);
 
   p->handle = dlopen(p->file, RTLD_NOW);
 
-  if (p->handle == NULL) {
+  if (NULL == p->handle) {
     error = dlerror();
     VERBOSE(fprintf(stderr, "[!] Failed to load plugin '%s': %s\n", p->name, error));
     xfree(p->name);
@@ -62,29 +62,16 @@ Plugin_load(Plugin_t *p)
   }
   fflush(stdout);
 
-  _tmp = (u_long *) dlsym(p->handle, "id");
-  if (_tmp == NULL) {
-    error = dlerror();
-    fprintf(stderr, "\n");
-    xerror("Plugin MUST define an id (%s)\n", error);
-  } else {
-    p->id = *_tmp;
-    if (libbiniou_verbose)
+  uint32_t *version_ptr = (uint32_t *) dlsym(p->handle, "version");
+  if (NULL != version_ptr) {
+    p->version = *version_ptr;
 #ifdef DEBUG
-      printf(" (id= %"PRIu32")\n", p->id);
-#else
-      printf("\n");
+    printf("plugin version: %d\n", p->version);
 #endif
   }
 
-  uint32_t *version_ptr = (uint32_t *) dlsym(p->handle, "version");
-  if (version_ptr != NULL) {
-    p->version = *version_ptr;
-    printf("plugin version: %d\n", p->version);
-  }
-
   _tmp = (u_long *) dlsym(p->handle, "options");
-  if (_tmp == NULL) {
+  if (NULL == _tmp) {
     error = dlerror();
     xerror("Plugin MUST define options (%s)\n", error);
   } else {
@@ -97,7 +84,7 @@ Plugin_load(Plugin_t *p)
   /* get display name */
   p->dname = (char *) dlsym(p->handle, "dname");
   B_GOTSYM(p->dname, "dname");
-  if (p->dname == NULL) {
+  if (NULL == p->dname) {
     p->dname = p->name;
   }
 
@@ -122,7 +109,7 @@ Plugin_load(Plugin_t *p)
   p->jthread = (void *(*)(void *)) dlsym(p->handle, "jthread");
   B_GOTSYM(p->jthread, "jthread");
 
-  p->parameters = (json_t *(*)(json_t *)) dlsym(p->handle, "parameters");
+  p->parameters = (json_t *(*)(struct Context_s *, json_t *)) dlsym(p->handle, "parameters");
 
   return p;
 }
@@ -131,10 +118,10 @@ Plugin_load(Plugin_t *p)
 static void
 Plugin_unload(Plugin_t *p)
 {
-  assert (p != NULL);
+  assert (NULL != p);
 
   /* FIXME error checking there, ie if plugin fails to destroy */
-  if (p->jthread != NULL) {
+  if (NULL != p->jthread) {
     VERBOSE(printf("[p] Joining thread from plugin '%s'... ", p->name));
     pthread_join(p->thread, NULL);
   } else {
@@ -146,7 +133,7 @@ Plugin_unload(Plugin_t *p)
     }
   }
 
-  if (p->destroy != NULL) {
+  if (NULL != p->destroy) {
     p->destroy(context);
   }
 
@@ -164,8 +151,8 @@ Plugin_new(const char *directory, const char *name, const enum PluginType type)
 {
   Plugin_t *p = xcalloc(1, sizeof(Plugin_t));
 
-  assert(name != NULL);
-  assert(directory != NULL);
+  assert(NULL != name);
+  assert(NULL != directory);
 
   p->name = strdup(name);
   p->calls = 0;
@@ -185,7 +172,7 @@ Plugin_new(const char *directory, const char *name, const enum PluginType type)
 void
 Plugin_delete(Plugin_t *p)
 {
-  assert(p != NULL);
+  assert(NULL != p);
   Plugin_unload(p);
   xfree(p->name);
   g_free(p->file);
@@ -196,7 +183,7 @@ Plugin_delete(Plugin_t *p)
 void
 Plugin_reload(Plugin_t *p)
 {
-  assert(p != NULL);
+  assert(NULL != p);
   Plugin_unload(p);
   Plugin_load(p);
   VERBOSE(printf("[p] Reloaded plugin '%s'\n", p->name));
@@ -207,14 +194,14 @@ int8_t
 Plugin_init(Plugin_t *p)
 {
   int8_t res = 1;
-  assert(p != NULL);
+  assert(NULL != p);
 
-  if (p->create != NULL) {
+  if (NULL != p->create) {
     VERBOSE(printf("[+] Initializing plugin %s\n", p->name));
     res = p->create(context);
   }
 
-  if ((p->jthread != NULL) && res) {
+  if ((NULL != p->jthread) && res) {
     pthread_create(&p->thread, NULL, p->jthread, (void *)context);
     VERBOSE(printf("[p] Launched thread %s\n", p->name));
   }
@@ -228,10 +215,10 @@ Plugin_uppercase(const char *str)
 {
   char *tmp;
 
-  assert(str != NULL);
+  assert(NULL != str);
   tmp = strdup(str);
 
-  assert(tmp != NULL);
+  assert(NULL != tmp);
   assert(tmp[0] != '\0');
   tmp[0] = (char)toupper((int)tmp[0]);
 
@@ -242,7 +229,7 @@ Plugin_uppercase(const char *str)
 char *
 Plugin_name(const Plugin_t *p)
 {
-  assert(p != NULL);
+  assert(NULL != p);
   return Plugin_uppercase(p->name);
 }
 
@@ -250,7 +237,7 @@ Plugin_name(const Plugin_t *p)
 char *
 Plugin_dname(const Plugin_t *p)
 {
-  assert(p != NULL);
+  assert(NULL != p);
   return Plugin_uppercase(p->dname);
 }
 
@@ -259,7 +246,7 @@ uint8_t
 plugin_parameter_number(json_t *in_parameters)
 {
   uint8_t n = 0;
-  for (void *iter = json_object_iter(in_parameters); iter != NULL; n++) {
+  for (void *iter = json_object_iter(in_parameters); NULL != iter; n++) {
     iter = json_object_iter_next(in_parameters, iter);
   }
   return n;
@@ -311,7 +298,7 @@ plugin_parameter_parse_int(const json_t *in_parameters, const char *name, int *v
 {
   json_t *p = json_object_get(in_parameters, name);
 
-  if (p != NULL) {
+  if (NULL != p) {
     json_t *j_value = json_object_get(p, "value");
     if (json_is_integer(j_value)) {
       *value = json_integer_value(j_value);
@@ -346,7 +333,7 @@ plugin_parameter_parse_double(const json_t *in_parameters, const char *name, dou
 {
   json_t *p = json_object_get(in_parameters, name);
 
-  if (p != NULL) {
+  if (NULL != p) {
     json_t *j_value = json_object_get(p, "value");
     if (json_is_real(j_value)) {
       *value = json_real_value(j_value);
@@ -359,23 +346,10 @@ plugin_parameter_parse_double(const json_t *in_parameters, const char *name, dou
 
 
 uint8_t
-plugin_parameter_parse_float(const json_t *in_parameters, const char *name, float *value)
+plugin_parameter_parse_double_range(const json_t *in_parameters, const char *name, double *value, double vmin, double vmax)
 {
-  double new_value;
+  double new_value = 0;
   uint8_t ret = plugin_parameter_parse_double(in_parameters, name, &new_value);
-  if (ret) {
-    *value = new_value;
-  }
-
-  return ret;
-}
-
-
-uint8_t
-plugin_parameter_parse_float_range(const json_t *in_parameters, const char *name, float *value, float vmin, float vmax)
-{
-  float new_value = 0;
-  uint8_t ret = plugin_parameter_parse_float(in_parameters, name, &new_value);
 
   if (new_value >= vmin && new_value <= vmax && ret == 1) {
     if (*value != new_value) {
@@ -394,7 +368,7 @@ plugin_parameter_parse_string(const json_t *in_parameters, const char *name, cha
 {
   json_t *p = json_object_get(in_parameters, name);
 
-  if (p != NULL) {
+  if (NULL != p) {
     json_t *j_value = json_object_get(p, "value");
     if (json_is_string(j_value)) {
       const char *str = json_string_value(j_value);
@@ -445,7 +419,7 @@ plugin_parameter_find_string_in_list(const json_t *in_parameters, const char *na
   const char *str = json_string_value(j_value);
 
   json_t *j_value_list = json_object_get(in_parameters, "value_list");
-  if (json_is_array(j_value_list) && (str != NULL)) {
+  if (json_is_array(j_value_list) && (NULL != str)) {
     for (uint32_t n = 0; n < (uint32_t)json_array_size(j_value_list); n++) {
       const char *list_str = json_string_value(json_array_get(j_value_list, n));
 
@@ -462,12 +436,12 @@ plugin_parameter_find_string_in_list(const json_t *in_parameters, const char *na
 
 
 json_t *
-plugin_parameter_change_selected(const char *delta, const float factor)
+plugin_parameter_change_selected(Context_t *ctx, const char *delta, const float factor)
 {
   json_t *ret = NULL;
 
-  if (plugins->selected->parameters != NULL) {
-    json_t *j_params = plugins->selected->parameters(NULL);
+  if (NULL != plugins->selected->parameters) {
+    json_t *j_params = plugins->selected->parameters(ctx, NULL);
     void *params_iter = json_object_iter(j_params);
     for (uint8_t n = 0; n < plugins->selected->selected_param; n++) {
       params_iter = json_object_iter_next(j_params, params_iter);
@@ -483,7 +457,7 @@ plugin_parameter_change_selected(const char *delta, const float factor)
 
         json_object_del(p, "value");
         json_object_set_new(p, "value", json_integer(value + delta));
-        ret = plugins->selected->parameters(j_params);
+        ret = plugins->selected->parameters(ctx, j_params);
 
       } else if (json_is_real(j_delta) && json_is_real(j_value)) {
         double delta = json_real_value(j_delta) * factor;
@@ -491,7 +465,7 @@ plugin_parameter_change_selected(const char *delta, const float factor)
 
         json_object_del(p, "value");
         json_object_set_new(p, "value", json_real(value + delta));
-        ret = plugins->selected->parameters(j_params);
+        ret = plugins->selected->parameters(ctx, j_params);
 
       } else if (json_is_integer(j_delta) && json_is_string(j_value)) {
         int delta = json_integer_value(j_delta) * factor;
@@ -511,7 +485,7 @@ plugin_parameter_change_selected(const char *delta, const float factor)
           const char *str = json_string_value(json_array_get(j_value_list, new_value));
           json_object_del(p, "value");
           json_object_set_new(p, "value", json_string(str));
-          ret = plugins->selected->parameters(j_params);
+          ret = plugins->selected->parameters(ctx, j_params);
         }
       }
     }
