@@ -33,7 +33,7 @@ Schemes_random(Context_t *ctx)
   char ok;
   uint16_t try = 0;
 
-  if ((schemes == NULL) || !schemes->size) {
+  if ((NULL == schemes) || !schemes->size) {
     printf("[!] No schemes available, leaving unchanged\n");
     return;
   }
@@ -45,14 +45,14 @@ Schemes_random(Context_t *ctx)
     gettimeofday(&t, NULL);
 
     ok = 1;
-    if ((schemes->shuffler != NULL) && !Shuffler_ok(schemes->shuffler)) {
+    if ((NULL != schemes->shuffler) && !Shuffler_ok(schemes->shuffler)) {
       printf("[!] Can not create a scheme, leaving unchanged\n");
       return;
     }
 
     Sequence_clear(new, t.tv_sec);
 
-    random = (schemes->shuffler != NULL) ? Shuffler_get(schemes->shuffler) : 0;
+    random = (NULL != schemes->shuffler) ? Shuffler_get(schemes->shuffler) : 0;
     for (i = 0; ok && schemes->schemes[random][i].type; i++) {
       /* check if we should insert a lens or a normal plugin */
       if (drand48() <= schemes->schemes[random][i].p) {
@@ -66,7 +66,7 @@ Schemes_random(Context_t *ctx)
 #ifdef DEBUG
           printf("[!] Marking scheme %d as invalid.\n", random);
 #endif
-          if (schemes != NULL) {
+          if (NULL != schemes) {
             Shuffler_disable(schemes->shuffler, random);
           }
           ok = 0;
@@ -75,7 +75,7 @@ Schemes_random(Context_t *ctx)
     }
 
     if (ok) {
-      if (ctx->locked != NULL) {
+      if (NULL != ctx->locked) {
         try++;
 #ifdef DEBUG
         fprintf(stderr, "=== Checking for locked plugin '%s' (try: %d)... ", ctx->locked->name, try);
