@@ -44,7 +44,7 @@ Sequence_t *Sequence_new(const uint32_t);
 void Sequence_delete(Sequence_t *);
 
 void Sequence_display(const Sequence_t *);
-void Sequence_copy(const Sequence_t *, Sequence_t *);
+void Sequence_copy(struct Context_s *, const Sequence_t *, Sequence_t *);
 void Sequence_clear(Sequence_t *, const uint32_t);
 void Sequence_changed(Sequence_t *);
 
@@ -55,7 +55,7 @@ void Sequence_remove(Sequence_t *, const Plugin_t *);
 GList *Sequence_find(const Sequence_t *, const Plugin_t *);
 short Sequence_find_position(const Sequence_t *, const Plugin_t *);
 
-void Sequence_save(Sequence_t *, int, const int, const uint8_t, const char, const char);
+void Sequence_save(struct Context_s *, Sequence_t *, int, const int, const uint8_t, const char, const char);
 Sequence_t *Sequence_load(const char *);
 
 gint Sequence_sort_func(gconstpointer, gconstpointer);
