@@ -1,6 +1,6 @@
 /*
- *  Copyright 1994-2019 Olivier Girondel
- *  Copyright 2019 Laurent Marsac
+ *  Copyright 1994-2020 Olivier Girondel
+ *  Copyright 2019-2020 Laurent Marsac
  *
  *  This file is part of lebiniou.
  *
@@ -377,8 +377,13 @@ bare_sequence:
     lens = !xmlStrcmp(plugins_node->name, (const xmlChar *)"lens");
 
     youhou = xmlGetProp(plugins_node, (const xmlChar *)"name");
-    p = Plugins_find((const char *)youhou);
-    if (NULL == p) {
+    if (NULL != youhou) {
+      p = Plugins_find((const char *)youhou);
+      xfree(youhou);
+      if (NULL == p) {
+        goto error;
+      }
+    } else {
       goto error;
     }
 
