@@ -78,7 +78,14 @@ Sequence_write_json(const Sequence_t *s, const char *filename, const uint8_t ful
 {
   json_t *sequence_j = Sequence_to_json(s, full);
   int ret = json_dump_file(sequence_j, filename, JSON_INDENT(4));
+
+  if (!ret) {
+    printf("[s] Saved sequence %s\n", filename);
+  } else {
+    printf("[s] ERROR: could not save sequence %s\n", filename);
+  }
   json_decref(sequence_j);
+
   return ret;
 }
 
@@ -104,18 +111,20 @@ Sequence_save(Context_t *ctx, Sequence_t *s, int overwrite, const int is_transie
     overwrite = 0;
   }
 
+  uint32_t old_id = s->id; // to restore if Sequence_write_json() fails
+  char *old_name = strdup(s->name); // ditto
+
   if (!overwrite || is_transient) {
+    xfree(s->name);
     s->id = unix_timestamp();
   }
 
   if (NULL == s->name) {
     s->name = g_strdup_printf("%" PRIu32, s->id);
   }
-  printf("[s] Saving sequence %" PRIu32 "\n", s->id);
 
   const gchar *blah = Sequences_get_dir();
   rmkdir(blah);
-  // g_free(blah);
 
   /* set auto_colormaps from context if needed */
   if (s->auto_colormaps == -1) {
@@ -135,17 +144,21 @@ Sequence_save(Context_t *ctx, Sequence_t *s, int overwrite, const int is_transie
     filename_json = g_strdup_printf("%s/%" PRIu32 ".json", blah, s->id);
   }
 
-  printf("[s] Filename: %s\n", filename_json);
-
-  if (Sequence_write_json(s, filename_json, bare) == 0 && overwrite) {
-    /* Erase old XML sequence */
-    FILE *fp = fopen(filename_xml, "r");
-    if (NULL != fp) {
-      fclose(fp);
-      if (remove(filename_xml) == 0) {
-        printf("[s] Removed old XML sequence %s\n", filename_xml);
+  if (!Sequence_write_json(s, filename_json, bare)) {
+    if (overwrite) {
+      /* Erase old XML sequence */
+      FILE *fp = fopen(filename_xml, "r");
+      if (NULL != fp) {
+        fclose(fp);
+        if (remove(filename_xml) == 0) {
+          printf("[s] Removed old XML sequence %s\n", filename_xml);
+        }
       }
     }
+    xfree(old_name);
+  } else { // saving failed, restore old id/name
+    s->id = old_id;
+    s->name = old_name;
   }
   g_free(filename_json);
   g_free(filename_xml);
