@@ -28,8 +28,9 @@
 enum BankMode { SEQUENCES=0, COLORMAPS, IMAGES };
 
 typedef struct SequenceManager_s {
-  Sequence_t *cur, *next, *transient;
-  GList      *curseq;
+  Sequence_t      *cur, *next, *transient;
+  GList           *curseq;
+  pthread_mutex_t mutex;
 } SequenceManager_t;
 
 
@@ -48,8 +49,11 @@ void SequenceManager_default_layer_mode(const Sequence_t *);
 void SequenceManager_prev_layer_mode(const Sequence_t *);
 void SequenceManager_next_layer_mode(const Sequence_t *);
 
-int SequenceManager_event(SequenceManager_t *, const Event_t *, const char, const char);
+int SequenceManager_event(struct Context_s *, const Event_t *, const char, const char);
 
 int SequenceManager_is_transient(const SequenceManager_t *, const Sequence_t *);
 
+void SequenceManager_lock(SequenceManager_t *);
+void SequenceManager_unlock(SequenceManager_t *);
+
 #endif /* __BINIOU_SEQUENCE_MANAGER_H */
