@@ -35,20 +35,20 @@ Sequences_new()
 
   dir = opendir(blah);
 
-  if (dir == NULL) {
+  if (NULL == dir) {
 #ifdef DEBUG
     printf("[!] No user sequences found: %s: %s\n", blah, strerror(errno));
 #endif
     // g_free(blah);
   } else {
     // g_free(blah);
-    while ((entry = readdir(dir)) != NULL) {
+    while (NULL != (entry = readdir(dir))) {
       if (strcmp(entry->d_name, "..")) {
         Sequence_t *s = NULL;
 
         s = Sequence_load(entry->d_name);
 
-        if (s != NULL) {
+        if (NULL != s) {
           sequences->seqs = g_list_insert_sorted(sequences->seqs, (gpointer)s, Sequence_sort_func);
         }
       }
@@ -71,13 +71,13 @@ Sequences_free()
 {
   GList *tmp;
 
-  if (sequences == NULL) {
+  if (NULL == sequences) {
     return;
   }
 
   tmp = sequences->seqs;
 
-  while (tmp != NULL) {
+  while (NULL != tmp) {
     Sequence_t *killme = (Sequence_t *)tmp->data;
 
     Sequence_delete(killme);
@@ -100,7 +100,7 @@ Sequences_find(const uint32_t id)
   assert(NULL != sequences);
   tmp = sequences->seqs;
 
-  while (tmp != NULL) {
+  while (NULL != tmp) {
     Sequence_t *s = (Sequence_t *)tmp->data;
 
     if (s->id == id) {
