@@ -64,7 +64,7 @@ process_options(const char *options)
 
   tokens = g_strsplit(options, ",", 0);
 
-  for (tok = tokens ; *tok != NULL; tok++) {
+  for (tok = tokens ; NULL != *tok; tok++) {
     process_token(*tok);
   }
 
